from lakefs_client.paths.auth_groups_group_id.get import ApiForget
from lakefs_client.paths.auth_groups_group_id.delete import ApiFordelete


class AuthGroupsGroupId(
    ApiForget,
    ApiFordelete,
):
    pass
