# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branch_protection.post import CreateBranchProtectionRule
from lakefs_client.paths.repositories.post import CreateRepository
from lakefs_client.paths.repositories_repository_branch_protection.delete import DeleteBranchProtectionRule
from lakefs_client.paths.repositories_repository.delete import DeleteRepository
from lakefs_client.paths.repositories_repository_branch_protection.get import GetBranchProtectionRules
from lakefs_client.paths.repositories_repository.get import GetRepository
from lakefs_client.paths.repositories.get import ListRepositories


class RepositoriesApi(
    CreateBranchProtectionRule,
    CreateRepository,
    DeleteBranchProtectionRule,
    DeleteRepository,
    GetBranchProtectionRules,
    GetRepository,
    ListRepositories,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
