from lakefs_client.paths.repositories_repository_tags_tag.get import ApiForget
from lakefs_client.paths.repositories_repository_tags_tag.delete import ApiFordelete


class RepositoriesRepositoryTagsTag(
    ApiForget,
    ApiFordelete,
):
    pass
