from lakefs_client.paths.auth_users_user_id.get import ApiForget
from lakefs_client.paths.auth_users_user_id.delete import ApiFordelete


class AuthUsersUserId(
    ApiForget,
    ApiFordelete,
):
    pass
