# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branches_branch_cherry_pick.post import CherryPick
from lakefs_client.paths.repositories_repository_branches.post import CreateBranch
from lakefs_client.paths.repositories_repository_branches_branch.delete import DeleteBranch
from lakefs_client.paths.repositories_repository_branches_branch_diff.get import DiffBranch
from lakefs_client.paths.repositories_repository_branches_branch.get import GetBranch
from lakefs_client.paths.repositories_repository_branches.get import ListBranches
from lakefs_client.paths.repositories_repository_branches_branch.put import ResetBranch
from lakefs_client.paths.repositories_repository_branches_branch_revert.post import RevertBranch


class BranchesApi(
    CherryPick,
    CreateBranch,
    DeleteBranch,
    DiffBranch,
    GetBranch,
    ListBranches,
    ResetBranch,
    RevertBranch,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
