from lakefs_client.paths.repositories_repository_branches.get import ApiForget
from lakefs_client.paths.repositories_repository_branches.post import ApiForpost


class RepositoriesRepositoryBranches(
    ApiForget,
    ApiForpost,
):
    pass
