from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.get import ApiForget
from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.delete import ApiFordelete


class AuthUsersUserIdCredentialsAccessKeyId(
    ApiForget,
    ApiFordelete,
):
    pass
