from lakefs_client.paths.repositories_repository_refs_ref_objects.get import ApiForget
from lakefs_client.paths.repositories_repository_refs_ref_objects.head import ApiForhead


class RepositoriesRepositoryRefsRefObjects(
    ApiForget,
    ApiForhead,
):
    pass
