# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_refs_branch_symlink.post import CreateSymlinkFile
from lakefs_client.paths.repositories_repository_metadata_meta_range_meta_range.get import GetMetaRange
from lakefs_client.paths.repositories_repository_metadata_range_range.get import GetRange


class MetadataApi(
    CreateSymlinkFile,
    GetMetaRange,
    GetRange,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
