# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.auth_groups_group_id_members_user_id.put import AddGroupMembership
from lakefs_client.paths.auth_groups_group_id_policies_policy_id.put import AttachPolicyToGroup
from lakefs_client.paths.auth_users_user_id_policies_policy_id.put import AttachPolicyToUser
from lakefs_client.paths.auth_users_user_id_credentials.post import CreateCredentials
from lakefs_client.paths.auth_groups.post import CreateGroup
from lakefs_client.paths.auth_policies.post import CreatePolicy
from lakefs_client.paths.auth_users.post import CreateUser
from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.delete import DeleteCredentials
from lakefs_client.paths.auth_groups_group_id.delete import DeleteGroup
from lakefs_client.paths.auth_groups_group_id_members_user_id.delete import DeleteGroupMembership
from lakefs_client.paths.auth_policies_policy_id.delete import DeletePolicy
from lakefs_client.paths.auth_users_user_id.delete import DeleteUser
from lakefs_client.paths.auth_groups_group_id_policies_policy_id.delete import DetachPolicyFromGroup
from lakefs_client.paths.auth_users_user_id_policies_policy_id.delete import DetachPolicyFromUser
from lakefs_client.paths.auth_password_forgot.post import ForgotPassword
from lakefs_client.paths.auth_capabilities.get import GetAuthCapabilities
from lakefs_client.paths.auth_users_user_id_credentials_access_key_id.get import GetCredentials
from lakefs_client.paths.user.get import GetCurrentUser
from lakefs_client.paths.auth_groups_group_id.get import GetGroup
from lakefs_client.paths.auth_policies_policy_id.get import GetPolicy
from lakefs_client.paths.auth_users_user_id.get import GetUser
from lakefs_client.paths.auth_groups_group_id_members.get import ListGroupMembers
from lakefs_client.paths.auth_groups_group_id_policies.get import ListGroupPolicies
from lakefs_client.paths.auth_groups.get import ListGroups
from lakefs_client.paths.auth_policies.get import ListPolicies
from lakefs_client.paths.auth_users_user_id_credentials.get import ListUserCredentials
from lakefs_client.paths.auth_users_user_id_groups.get import ListUserGroups
from lakefs_client.paths.auth_users_user_id_policies.get import ListUserPolicies
from lakefs_client.paths.auth_users.get import ListUsers
from lakefs_client.paths.auth_login.post import Login
from lakefs_client.paths.auth_password.post import UpdatePassword
from lakefs_client.paths.auth_policies_policy_id.put import UpdatePolicy


class AuthApi(
    AddGroupMembership,
    AttachPolicyToGroup,
    AttachPolicyToUser,
    CreateCredentials,
    CreateGroup,
    CreatePolicy,
    CreateUser,
    DeleteCredentials,
    DeleteGroup,
    DeleteGroupMembership,
    DeletePolicy,
    DeleteUser,
    DetachPolicyFromGroup,
    DetachPolicyFromUser,
    ForgotPassword,
    GetAuthCapabilities,
    GetCredentials,
    GetCurrentUser,
    GetGroup,
    GetPolicy,
    GetUser,
    ListGroupMembers,
    ListGroupPolicies,
    ListGroups,
    ListPolicies,
    ListUserCredentials,
    ListUserGroups,
    ListUserPolicies,
    ListUsers,
    Login,
    UpdatePassword,
    UpdatePolicy,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
