from lakefs_client.paths.auth_groups_group_id_policies_policy_id.put import ApiForput
from lakefs_client.paths.auth_groups_group_id_policies_policy_id.delete import ApiFordelete


class AuthGroupsGroupIdPoliciesPolicyId(
    ApiForput,
    ApiFordelete,
):
    pass
