# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_gc_rules.delete import DeleteGarbageCollectionRules
from lakefs_client.paths.repositories_repository_gc_rules.get import GetGarbageCollectionRules
from lakefs_client.paths.repositories_repository_gc_prepare_commits.post import PrepareGarbageCollectionCommits
from lakefs_client.paths.repositories_repository_gc_prepare_uncommited.post import PrepareGarbageCollectionUncommitted
from lakefs_client.paths.repositories_repository_gc_rules.post import SetGarbageCollectionRules


class RetentionApi(
    DeleteGarbageCollectionRules,
    GetGarbageCollectionRules,
    PrepareGarbageCollectionCommits,
    PrepareGarbageCollectionUncommitted,
    SetGarbageCollectionRules,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
